@@ -20,19 +20,32 @@
 
 import os
 
-from ansiblelint import AnsibleLintRule
+from ansiblelint.rules import AnsibleLintRule
+from ansiblelint.utils import get_first_cmd_arg
+
 try:
-    from ansible.utils.boolean import boolean
+    from ansible.module_utils.parsing.convert_bool import boolean
 except ImportError:
-    from ansible.utils import boolean
+    try:
+        from ansible.utils.boolean import boolean
+    except ImportError:
+        try:
+            from ansible.utils import boolean
+        except ImportError:
+            from ansible import constants
+            boolean = constants.mk_boolean
 
 
 class CommandsInsteadOfArgumentsRule(AnsibleLintRule):
-    id = 'ANSIBLE0007'
+    id = '302'
     shortdesc = 'Using command rather than an argument to e.g. file'
-    description = 'Executing a command when there is are arguments to modules ' + \
-                  'is generally a bad idea'
-    tags = ['resources']
+    description = (
+        'Executing a command when there are arguments to modules '
+        'is generally a bad idea'
+    )
+    severity = 'VERY_HIGH'
+    tags = ['command-shell', 'resources', 'ANSIBLE0007']
+    version_added = 'historic'
 
     _commands = ['command', 'shell', 'raw']
     _arguments = {'chown': 'owner', 'chmod': 'mode', 'chgrp': 'group',
@@ -40,8 +53,12 @@ class CommandsInsteadOfArgumentsRule(AnsibleLintRule):
                   'rmdir': 'state=absent', 'rm': 'state=absent'}
 
     def matchtask(self, file, task):
-        if task["action"]["module"] in self._commands and task["action"]["module_arguments"]:
-            executable = os.path.basename(task["action"]["module_arguments"][0])
+        if task["action"]["__ansible_module__"] in self._commands:
+            first_cmd_arg = get_first_cmd_arg(task)
+            if not first_cmd_arg:
+                return
+
+            executable = os.path.basename(first_cmd_arg)
             if executable in self._arguments and \
                     boolean(task['action'].get('warn', True)):
                 message = "{0} used in place of argument {1} to file module"
