@@ -18,16 +18,20 @@
 # OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 # THE SOFTWARE.
 
-from ansiblelint import AnsibleLintRule
+from ansiblelint.rules import AnsibleLintRule
 
 
 class GitHasVersionRule(AnsibleLintRule):
-    id = 'ANSIBLE0004'
+    id = '401'
     shortdesc = 'Git checkouts must contain explicit version'
-    description = 'All version control checkouts must point to ' + \
-                  'an explicit commit or tag, not just "latest"'
-    tags = ['repeatability']
+    description = (
+        'All version control checkouts must point to '
+        'an explicit commit or tag, not just ``latest``'
+    )
+    severity = 'MEDIUM'
+    tags = ['module', 'repeatability', 'ANSIBLE0004']
+    version_added = 'historic'
 
     def matchtask(self, file, task):
-        return (task['action']['module'] == 'git' and
+        return (task['action']['__ansible_module__'] == 'git' and
                 task['action'].get('version', 'HEAD') == 'HEAD')
