@@ -18,17 +18,20 @@
 # OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 # THE SOFTWARE.
 
-from ansiblelint import AnsibleLintRule
+from ansiblelint.rules import AnsibleLintRule
 
 
 class MercurialHasRevisionRule(AnsibleLintRule):
-    id = 'ANSIBLE0005'
+    id = '402'
     shortdesc = 'Mercurial checkouts must contain explicit revision'
-    description = 'All version control checkouts must point to ' + \
-                  'an explicit commit or tag, not just "latest"'
-
-    tags = ['repeatability']
+    description = (
+        'All version control checkouts must point to '
+        'an explicit commit or tag, not just ``latest``'
+    )
+    severity = 'MEDIUM'
+    tags = ['module', 'repeatability', 'ANSIBLE0005']
+    version_added = 'historic'
 
     def matchtask(self, file, task):
-        return (task['action']['module'] == 'hg' and
+        return (task['action']['__ansible_module__'] == 'hg' and
                 task['action'].get('revision', 'default') == 'default')
