@@ -19,44 +19,59 @@
 # THE SOFTWARE.
 from ansiblelint.rules import AnsibleLintRule
 
+# Despite documentation mentioning 'preserve' only these modules support it:
+_modules_with_preserve = (
+    'copy',
+    'template',
+)
+
 
 class MissingFilePermissionsRule(AnsibleLintRule):
     id = "208"
-    shortdesc = 'File permissions not mentioned'
+    shortdesc = 'File permissions unset or incorrect'
     description = (
-        "Missing mode parameter can cause unexpected file permissions based "
-        "on version of Ansible being used. Be explicit, or if you still "
-        "want the default behavior you can use ``mode: preserve`` to avoid "
-        "hitting this rule. See "
-        "https://github.com/ansible/ansible/issues/71200"
+        "Missing or unsupported mode parameter can cause unexpected file "
+        "permissions based "
+        "on version of Ansible being used. Be explicit, like ``mode: 0644`` to "
+        "avoid hitting this rule. Special ``preserve`` value is accepted "
+        f"only by {', '.join(_modules_with_preserve)} modules. "
+        "See https://github.com/ansible/ansible/issues/71200"
     )
     severity = 'VERY_HIGH'
-    tags = ['unpredictability']
+    tags = ['unpredictability', 'experimental']
     version_added = 'v4.3.0'
 
-    _modules = (
-        'assemble',
+    _modules = {
         'archive',
-        'copy',
+        'assemble',
+        'copy',  # supports preserve
         'file',
-        'template',
-        'unarchive',
-    )
+        'replace',  # implicit preserve behavior but mode: preserve is invalid
+        'template',  # supports preserve
+        # 'unarchive',  # disabled because .tar.gz files can have permissions inside
+    }
 
-    _modules_with_create = (
-        'blockinfile',
-        'ini_file',
-        'lineinfile'
-    )
+    _modules_with_create = {
+        'blockinfile': False,
+        'htpasswd': True,
+        'ini_file': True,
+        'lineinfile': False,
+    }
 
     def matchtask(self, file, task):
-        if task["action"]["__ansible_module__"] not in self._modules and \
-                task["action"]["__ansible_module__"] not in self._modules_with_create:
+        module = task["action"]["__ansible_module__"]
+        mode = task['action'].get('mode', None)
+
+        if module not in self._modules and \
+                module not in self._modules_with_create:
             return False
 
-        if task["action"]["__ansible_module__"] in self._modules_with_create and \
-                not task["action"].get("create", False):
-            return False
+        if mode == 'preserve' and module not in _modules_with_preserve:
+            return True
+
+        if module in self._modules_with_create:
+            create = task["action"].get("create", self._modules_with_create[module])
+            return create and mode is None
 
         # A file that doesn't exist cannot have a mode
         if task['action'].get('state', None) == "absent":
@@ -67,9 +82,14 @@ class MissingFilePermissionsRule(AnsibleLintRule):
             return False
 
         # The file module does not create anything when state==file (default)
-        if task["action"]["__ansible_module__"] == "file" and \
+        if module == "file" and \
                 task['action'].get('state', 'file') == 'file':
             return False
 
-        mode = task['action'].get('mode', None)
+        # replace module is the only one that has a valid default preserve
+        # behavior, but we want to trigger rule if user used incorrect
+        # documentation and put 'preserve', which is not supported.
+        if module == 'replace' and mode is None:
+            return False
+
         return mode is None
