@@ -1,11 +1,13 @@
-from ansiblelint import AnsibleLintRule
+from ansiblelint.rules import AnsibleLintRule
 
 
 class SudoRule(AnsibleLintRule):
-    id = 'ANSIBLE0008'
+    id = '103'
     shortdesc = 'Deprecated sudo'
-    description = 'Instead of sudo/sudo_user, use become/become_user.'
-    tags = ['deprecated']
+    description = 'Instead of ``sudo``/``sudo_user``, use ``become``/``become_user``.'
+    severity = 'VERY_HIGH'
+    tags = ['deprecated', 'ANSIBLE0008']
+    version_added = 'historic'
 
     def _check_value(self, play_frag):
         results = []
@@ -13,10 +15,14 @@ class SudoRule(AnsibleLintRule):
         if isinstance(play_frag, dict):
             if 'sudo' in play_frag:
                 results.append(({'sudo': play_frag['sudo']},
-                                'deprecated sudo feature'))
+                                'Deprecated sudo feature', play_frag['__line__']))
             if 'sudo_user' in play_frag:
                 results.append(({'sudo_user': play_frag['sudo_user']},
-                                'deprecated sudo_user feature'))
+                                'Deprecated sudo_user feature', play_frag['__line__']))
+            if 'tasks' in play_frag:
+                output = self._check_value(play_frag['tasks'])
+                if output:
+                    results += output
 
         if isinstance(play_frag, list):
             for item in play_frag:
