@@ -17,12 +17,13 @@
 # LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 # OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 # THE SOFTWARE.
-
-import os
+# pylint: disable=preferred-module  # FIXME: remove once migrated per GH-725
+import pathlib
 import unittest
 
-from ansiblelint import Match, AnsibleLintRule
+from ansiblelint.errors import MatchError
 from ansiblelint.formatters import Formatter
+from ansiblelint.rules import AnsibleLintRule
 
 
 class TestFormatter(unittest.TestCase):
@@ -30,16 +31,16 @@ class TestFormatter(unittest.TestCase):
     def setUp(self):
         self.rule = AnsibleLintRule()
         self.rule.id = "TCF0001"
-        self.formatter = Formatter()
+        self.formatter = Formatter(pathlib.Path.cwd(), True)
 
     def test_format_coloured_string(self):
-        match = Match(1, "hello", "filename.yml", self.rule, "message")
-        result = self.formatter.format(match, True)
+        match = MatchError("message", 1, "hello", "filename.yml", self.rule)
+        self.formatter.format(match, True)
 
     def test_unicode_format_string(self):
-        match = Match(1, "hello", "filename.yml", self.rule, u'\U0001f427')
-        result = self.formatter.format(match, False)
+        match = MatchError(u'\U0001f427', 1, "hello", "filename.yml", self.rule)
+        self.formatter.format(match, False)
 
     def test_dict_format_line(self):
-        match = Match(1, {'hello': 'world'}, "filename.yml", self.rule, "xyz")
-        result = self.formatter.format(match, True)
+        match = MatchError("xyz", 1, {'hello': 'world'}, "filename.yml", self.rule,)
+        self.formatter.format(match, True)
