@@ -242,6 +242,7 @@ def test_logger_debug(caplog):
     assert expected_info in caplog.record_tuples
 
 
+@pytest.mark.xfail
 def test_cli_auto_detect(capfd):
     """Test that run without arguments it will detect and lint the entire repository."""
     cmd = sys.executable, "-m", "ansiblelint", "-v", "-p", "--nocolor"
@@ -262,6 +263,14 @@ def test_cli_auto_detect(capfd):
         "[E401] Git checkouts must contain explicit version" in out
     # assures that our .ansible-lint exclude was effective in excluding github files
     assert "Unknown file type: .github/" not in out
+    # assures that we can parse playbooks as playbooks
+    assert "Unknown file type: test/test/always-run-success.yml" not in err
+
+
+@pytest.mark.xfail
+def test_is_playbook():
+    """Verify that we can detect a playbook as a playbook."""
+    assert utils.is_playbook("test/test/always-run-success.yml")
 
 
 def test_auto_detect_exclude(monkeypatch):
