@@ -1,4 +1,4 @@
-from ansiblelint import AnsibleLintRule
+from ansiblelint.rules import AnsibleLintRule
 
 
 class EMatcherRule(AnsibleLintRule):
@@ -6,7 +6,7 @@ class EMatcherRule(AnsibleLintRule):
     description = 'This is a test rule that looks for lines ' + \
                   'containing the letter e'
     shortdesc = 'The letter "e" is present'
-    tags = {'fake', 'dummy', 'test1'}
+    tags = ['fake', 'dummy', 'test1']
 
     def match(self, filename, line):
         return "e" in line
